<?php

declare(strict_types=1);

namespace Drupal\ga4_server_events\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure GA4 Server Events settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'ga4_server_events_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['ga4_server_events.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $this->messenger()->addWarning('For the module to function correctly, the gtag script must be installed on the site (integration with Google Analytics 4 directly or through Google Tag Manager');
    $form['measurement_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Measurement ID'),
      '#default_value' => $this->config('ga4_server_events.settings')->get('measurement_id'),
      '#description' => $this->t('The Measurement ID is a unique identifier that corresponds to the web stream that you want to send data to. You can find this ID in the GA4 interface under Admin > Data Streams > Web stream > Measurement ID.'),
      '#required' => TRUE,
    ];
    $form['api_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Secret'),
      '#default_value' => $this->config('ga4_server_events.settings')->get('api_secret'),
      '#description' => $this->t('The API Secret generated in the Google Analytics UI. To create a new secret, navigate to Admin > Data Streams > choose your stream > Measurement Protocol > Create.'),
      '#required' => TRUE,
    ];
    $form['disable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable'),
      '#default_value' => $this->config('ga4_server_events.settings')->get('disable'),
      '#description' => $this->t('Check this box to disable the GA4 Server Events module. This will prevent any data from being sent to Google Analytics.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('ga4_server_events.settings')
      ->set('measurement_id', $form_state->getValue('measurement_id'))
      ->set('api_secret', $form_state->getValue('api_secret'))
      ->set('disable', $form_state->getValue('disable'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
